<?php

ini_set('max_execution_time', 300); //300 seconds = 5 minutes

require_once('Slim/Slim.php');
require_once('includes/_dbconfig.php');

date_default_timezone_set('Africa/Nairobi');

\Slim\Slim::registerAutoloader();

$app = new \Slim\Slim();


$app->post('/survey/new/', 'addSurvey');
$app->get('/survey/all/', 'getSurveys');
$app->get('/survey/companies/', 'getCompanies');


$app->run();




/**
 * Function Name: getCompanies
 *
 * Returns the full list of companies
 *
 * @param (array) ([companies details]) the companies details
 * @return (number) ($rows) the number of rows added
 *
 */
function getCompanies() {	
	
	$sql = "SELECT id,company_name,email_address,industry,take_survey FROM companies";
	    
	    try {	
	    			    	
	    	$db = getConnection();
			$stmt = $db->prepare($sql);
			$rows = $stmt->execute();
			$companies = $stmt->fetchAll(PDO::FETCH_OBJ);						

			$db = null;

			$data = array('success' => true, 'companies' => $companies);
			echo json_encode($data);
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}







/**
 * Function Name: getSurveys
 *
 * Returns the full list of surveys
 *
 * @param (array) ([surveys details]) the surveys details
 * @return (number) ($rows) the number of rows added
 *
 */
function getSurveys() {	
	
	$sql = "SELECT s.id, company_id, c.company_name, question_one, question_two, question_three, question_four, quality_of_our_proposals, costs, project_execution, communication, creativity_and_innovation, customer_support FROM survey as s INNER JOIN companies as c ON s.company_id = c.id";
	    
	    try {	
	    			    	
	    	$db = getConnection();
			$stmt = $db->prepare($sql);
			$rows = $stmt->execute();
			$surveys = $stmt->fetchAll(PDO::FETCH_OBJ);						

			$db = null;

			$data = array('success' => true, 'surveys' => $surveys);
			echo json_encode($data);
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}





/**
 * Function Name: addSurvey
 *
 * Adds a new feedback survey
 *
 * @param (array) ([survey details]) the survey details
 * @return (number) ($rows) the number of rows added
 *
 */
function addSurvey() {
	
	$request = \Slim\Slim::getInstance()->request();
	
	$survey = json_decode($request->getBody());//true makes the result as an array object

	$sql = "INSERT INTO survey (company_id, question_one, question_two, question_three, question_four, quality_of_our_proposals, costs, project_execution, communication, creativity_and_innovation, customer_support) VALUES (:company_id, :question_one, :question_two, :question_three, :question_four, :quality_of_our_proposals, :costs, :project_execution, :communication, :creativity_and_innovation, :customer_support)";
	    
	    try {	    	

	    	$company_id = $survey->company_id;	    	
	    	$question_one = $survey->question_one;
			$question_two = $survey->question_two;
			$question_three = $survey->question_three;
			$question_four = $survey->question_four;
			$quality_of_our_proposals = $survey->quality_of_our_proposals;
			$costs = $survey->costs;
			$project_execution = $survey->project_execution;
			$communication = $survey->communication;
			$creativity_and_innovation = $survey->creativity_and_innovation;
			$customer_support = $survey->customer_support;	    	   	   		
	    			    	
	    	$db = getConnection();
			$stmt = $db->prepare($sql);			
			
			$stmt->bindParam("company_id", $company_id);			
			$stmt->bindParam("question_one", $question_one);
			$stmt->bindParam("question_two", $question_two);
			$stmt->bindParam("question_three", $question_three);
			$stmt->bindParam("question_four", $question_four);
			$stmt->bindParam("quality_of_our_proposals", $quality_of_our_proposals);
			$stmt->bindParam("costs", $costs);
			$stmt->bindParam("project_execution", $project_execution);	
			$stmt->bindParam("communication", $communication);	
			$stmt->bindParam("creativity_and_innovation", $creativity_and_innovation);	
			$stmt->bindParam("customer_support", $customer_support);			
			
			$rows = $stmt->execute();			

			$db = null;

			if($rows > 0){
				
				$message = 'Thank you for taking the survey. We wish you a Merry Christmas and a happy new year';
				$data = array('success' => true, 'message' => $message);
				echo json_encode($data);					    
			    
			}else{
		    	
		    	$data = array('success' => false, 'message' => 'Sorry unable to process your data');
				echo json_encode($data);
		    }
	    
		    
	    
	    } catch(PDOException $e) {		
		     
		    $data = array('success' => false, 'message' => $e->getMessage());
			echo json_encode($data);
	    }		   
	
}





function cleanField($text){	
	
	$name = preg_replace("/[^a-zA-Z0-9\/_|+,<>() .-]/", '', $text);//remove special characters
	$name = preg_replace("/[\"\']/", '', $name); //remove any quotes

	return $name;
}


?>
